from setuptools import setup

setup(name='drf_requests_jwt',
      version='0.1',
      description='Django Rest Framework Requests with JWT support',
      url='https://github.com/sensidev/drf-requests-jwt',
      author='Sensidev',
      author_email='lucian.corduneanu@sensidev.com',
      license='MIT',
      packages=['drf_requests_jwt'],
      zip_safe=False)
